.. _spkg_sagemath_ecl:

=========================================================================
sagemath_ecl: Embeddable Common Lisp
=========================================================================


This pip-installable distribution ``passagemath-ecl`` is a distribution of a part of the Sage Library.
It ships the Cython interface to Embeddable Common Lisp.


What is included
----------------

* Binary wheels on PyPI contain a prebuilt copy of
  `Embeddable Common Lisp <https://passagemath.org/docs/latest/html/en/reference/spkg/ecl.html>`_


Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_cysignals`
- :ref:`spkg_cython`
- :ref:`spkg_ecl`
- :ref:`spkg_gmpy2`
- :ref:`spkg_gsl`
- :ref:`spkg_maxima`
- :ref:`spkg_pkgconfig`
- :ref:`spkg_python_build`
- :ref:`spkg_sage_setup`
- :ref:`spkg_sagemath_categories`
- :ref:`spkg_sagemath_environment`
- :ref:`spkg_singular`

Version Information
-------------------

package-version.txt::

    10.6.4

version_requirements.txt::

    passagemath-ecl ~= 10.6.4.0

Equivalent System Packages
--------------------------

(none known)
